===============
tricircleclient
===============

Python bindings to the OpenStack Tricircle API

This is a client for OpenStack Tricircle API. There's :doc:`a Python API
<api>` (the :mod:`tricircleclient` module), and a :doc:`command-line script
<shell>` (installed as :program:`tricircle`). Each implements the entire
OpenStack Tricircle API.

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/python-tricircleclient
* Source: http://git.openstack.org/cgit/openstack/python-tricircleclient
* Bugs: http://bugs.launchpad.net/python-tricircleclient
